@@ -17,6 +17,7 @@ class DialogModule(Module):
             *self.__args,
             question=self.__question,
             name=name,
+            meta_build=True,
             meta_module=self,
             **self.__kwargs)
         setattr(type(self), name, var)
@@ -25,5 +26,4 @@ class DialogModule(Module):
 
     @property
     def meta_docstring(self):
-        return self.meta_inspect(
-            name='docstring', lookup=True, default='DialogModule')
+        return self.meta_inspect('docstring', default='DialogModule')
