@@ -12,7 +12,7 @@ class DialogTaskTest(unittest.TestCase):
     def setUp(self):
         self.args = ('arg1',)
         self.kwargs = {'kwarg1': 'kwarg1'}
-        self.ptask = partial(component.DialogTask, meta_module=None)
+        self.ptask = partial(component.DialogTask, meta_build=True)
 
     # Tests
 
